Skip to contents

Function to check that required environment variables for APPS authentication are set and valid

Usage

check_secrets(verbose = F)

Arguments

verbose

logical; if TRUE, prints the current values of relevant environment variables (masking secrets) to the console