Skip to contents

Allows for global variable assignment and function definitions to be accessible by the server function.

Usage

global_wrapper(code)

Arguments

code

A block of R code

Value

The result of evaluating the code block in the Global Environment