Skip to contents

Provides a consistent navbar and footer, and handles authentication redirects.

Usage

ui_wrapper(...)

Arguments

...

Additional UI elements to include in the main content area

Value

A Shiny UI object with a navbar, footer, and main content area