Function to check that required environment variables for APPS authentication are set and valid
Source:R/utils.R
check_secrets.RdFunction to check that required environment variables for APPS authentication are set and valid

R/utils.R
check_secrets.RdFunction to check that required environment variables for APPS authentication are set and valid