R/shiny.R
global_wrapper.Rd
Allows for global variable assignment and function definitions to be accessible by the server function.
global_wrapper(code)
A block of R code
The result of evaluating the code block in the Global Environment