R/shiny.R
ui_wrapper.Rd
Provides a consistent navbar and footer, and handles authentication redirects.
ui_wrapper(...)
Additional UI elements to include in the main content area
A Shiny UI object with a navbar, footer, and main content area